@@ -1,7 +1,8 @@
-use boar::{Boar, BoarStr as Str};
+use boar::{Boar, BoarTo};
 use std::collections::HashMap;
 
 type BoarArray<'b, T, const N: usize> = Boar<'b, [T], [T; N]>;
+type Str<'b> = BoarTo<'b, str>;
 
 #[test]
 fn cmp() {
